@@ -33,47 +33,44 @@ given as parameter to the C<do> method and stores the parsed data from this obje
 
 =head1 METHODS
 
-=head2 do
+=head2 do_parsed
 
-This method is overrided from the superclass method, that is still called to validate parameter given.
-
-It will search in the array reference given as parameter: the first object found is serialized to the filesystem
-and the function returns 1 in this case. Otherwise it will return 0.
+It will check if the object given as parameter is a L<Siebel::Srvrmgr::ListParser::Output::ListParams> object. If true, it is serialized to the 
+filesystem with C<nstore> and the function returns 1 in this case. If none is found it will return 0.
 
 =cut
 
-sub do {
+override 'do_parsed' => sub {
 
-    my $self   = shift;
-    my $buffer = shift;    # array reference
+    my $self = shift;
+    my $obj  = shift;
 
-	super();
+    if ( $obj->isa( $self->get_exp_output() ) ) {
 
-    $self->get_parser()->parse($buffer);
+        $obj->store( $self->get_dump_file() );
 
-    my $tree = $self->get_parser()->get_parsed_tree();
+        return 1;
 
-    foreach my $obj ( @{$tree} ) {
+    }
+    else {
 
-        if ( $obj->isa('Siebel::Srvrmgr::ListParser::Output::ListParams') ) {
+        return 0;
 
-            $obj->store( $self->get_dump_file() );
+    }
 
-            return 1;
+};
 
-        }
+override '_build_exp_output' => sub {
 
-    }    # end of foreach block
+    return 'Siebel::Srvrmgr::ListParser::Output::Tabular::ListParams';
 
-    return 0;
-
-}
+};
 
 =pod
 
 =head1 SEE ALSO
 
-=over 2
+=over
 
 =item *
 
@@ -87,11 +84,11 @@ L<Siebel::Srvrmgr::Daemon::Action::Serializable>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel Monitoring Tools.
 
