@@ -62,14 +62,14 @@ use namespace::autoclean;
 use Siebel::Srvrmgr::Daemon::ActionFactory;
 use Siebel::Srvrmgr::ListParser;
 use Siebel::Srvrmgr::Daemon::Command;
-use POSIX;
 use Scalar::Util qw(weaken);
 use Config;
 use Carp qw(longmess);
-use File::Temp;
+use File::Temp qw(:POSIX);
 use Data::Dumper;
 use Siebel::Srvrmgr;
 use File::BOM qw(:all);
+use Siebel::Srvrmgr::IPC qw(check_system);
 
 extends 'Siebel::Srvrmgr::Daemon';
 
@@ -130,10 +130,12 @@ to execute L<Siebel::Srvrmgr::Daemon::Command> instances in parallel.
 
 =cut
 
-sub run {
+override 'run' => sub {
 
     my $self = shift;
 
+    super();
+
     my $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
     weaken($logger);
     $logger->info('Starting run method');
@@ -163,11 +165,13 @@ sub run {
 
     }
 
+# :TODO:22-09-2014 01:32:45:: this might be dangerous if the output is too large
     my @input_buffer = <$in>;
     close($in);
 
     if ( scalar(@input_buffer) >= 1 ) {
 
+        $self->_check_error( \@input_buffer, $logger );
         $self->normalize_eol( \@input_buffer );
         chomp(@input_buffer);
 
@@ -232,7 +236,7 @@ sub run {
 
     return 1;
 
-}
+};
 
 =pod
 
@@ -326,12 +330,12 @@ override _setup_commands => sub {
 
     my $self = shift;
 
-# :WORKAROUND:03/10/2013 03:06:41:: getting a "tmpnam redefined" warning in Perl 5.18
-    my ( $fh, $input_file ) = File::Temp::tmpnam();
+    super();
+
+    my ( $fh, $input_file ) = tmpnam();
 
     foreach my $cmd ( @{ $self->get_commands() } ) {
 
-        $self->_check_cmd( $cmd->get_command() );
         print $fh $cmd->get_command(), "\n";
 
     }
@@ -377,8 +381,7 @@ override _define_params => sub {
 
     my $params_ref = super();
 
-# :TODO      :20/08/2013 12:31:36:: must define if the output files must be kept or removed
-    $self->_set_output_file( scalar( File::Temp::tmpnam() ) );
+    $self->_set_output_file( scalar( tmpnam() ) );
 
     push(
         @{$params_ref},
@@ -413,7 +416,6 @@ sub _manual_check {
 
 }
 
-# :TODO:18-10-2013:arfreitas: this should be done by IPC.pm module?
 sub _check_system {
 
     my $self   = shift;
@@ -423,53 +425,37 @@ sub _check_system {
     my $ret_code    = shift;
     my $error_code  = shift;
 
-    if ( $Config{osname} eq 'MSWin32' ) {
+    my ( $message, $is_error ) = check_system($child_error);
+
+    unless ( ( defined($message) ) and ( defined($is_error) ) ) {
 
         $self->_manual_check( $logger, $ret_code, $error_code );
 
     }
     else {
 
-      SWITCH: {
+        if ( defined($is_error) ) {
 
-            if ( WIFEXITED($child_error) ) {
+            if ($is_error) {
 
-                $logger->info(
-'Child process terminate with call to exit() with return code = '
-                      . WEXITSTATUS($child_error) );
-                last SWITCH;
-
-            }
-
-            if ( WIFSIGNALED($child_error) ) {
-
-                $logger->logdie( 'Child process terminated due signal: '
-                      . WTERMSIG($child_error) );
-                last SWITCH;
-
-            }
-
-            if ( WIFSTOPPED($child_error) ) {
-
-                $logger->logdie( 'Child process was stopped with '
-                      . WSTOPSIG($child_error) );
-                last SWITCH;
+                $logger->logdie($message);
 
             }
             else {
 
-                $self->_manual_check( $logger, $ret_code, $error_code );
+                $logger->info($message);
 
             }
 
         }
+        else {
 
-        $self->_manual_check( $logger, $ret_code, $error_code );
+            $logger->info( $message . "Error code is $error_code" );
+
+        }
 
     }
 
-    return 1;
-
 }
 
 =pod
